#!/bin/bash
#
# install.sh - install script for bootsplash progress bar support
#
#

PWD="`pwd`"

if [ "$UID" -ne "0" ]; then
	echo "$0 must be started as root!"
	echo "Exiting..."
	exit 1
fi
#
# Check for epm
#
if [ ! -x /usr/bin/epm ]; then
	echo "$0 depends on package 'epm'"
	echo "Please run $0 a second time after you have emerged 'epm'"
	exit 1
fi
#
# Check for previous applied patch
#
if [ -n "`grep splash_init /sbin/rc`" -o -n "`grep splash_init /sbin/functions.sh`" ]; then
	echo "I found an older version of the bootsplash-patch !"
	echo "Please run $0 a second time after you have emerged"
	echo "the baselayout package (this will remove the old version)"
	exit 0
fi
#
# Check baselayout version
#
BVERSION="`epm -q baselayout | cut -d '-' -f 2`"
#
# Get patch versions and compare them to the baselayout version
#
for diff in *.diff; do
	name="${diff%.*}"
	version="`echo $name | cut -d '-' -f 3`"
	patches="$patches $version"

	if [ "$BVERSION" == "$version" ]; then
		echo "Your baselayout version is '$BVERSION', taking '${name%-*}-${version}.diff'"
		found="true"
		break
	fi
done

if [ -z "$found" ]; then
	cat << EOF
*****************************************************************
* WARNING: You do not have any version of the baselayout package 
* supported by this script. The versions should match, because I
* have to patch some files out of the baselayout package
* (/sbin/rc, /sbin/functions.sh, /etc/init.d/halt.sh).
* If you want to proceed, I will make a backup of each file
* (/sbin/rc~, /sbin/functions.sh~, /etc/init.d/halt.sh~).
* Otherwise read the INSTALL file how to manually patch the files.
******************************************************************

EOF
	echo -n "Should I proceed ? (y/n): "
	read input
	[ "$input" != "y" ] && exit 0

	#
	# Touch the numbered versions (simplifies the output) 
	#
	mkdir .versions 2>/dev/null
	num=0
	for version in $patches; do
		num=$(($num + 1))
		touch ".versions/${num}) ${version}"
	done

	echo
	echo "Ok, your baselayout version is '$BVERSION'"
	echo "Please choose a patch version that is close"
	echo "to your baselayout version from the list below:"
	echo
	cd .versions && ls *\)* && cd ../
	echo
	declare -i input
	while true; do
		echo -n "Which patch should I use ? (1-$num): "
		read input

		if [ $input -lt 1 -o $input -gt $num ]; then
			echo "  $input out of range, please try again"
		else
			break
		fi
	done
	echo
	#
	# Get patch version
	#
	version="`ls .versions/${input}\)* | cut -d ' ' -f 2 `"
fi
#
# Get the name of the patch and apply it
#
patch="${name%-*}-${version}.diff"

echo "Applying patch '$patch':"
patch -d / -p 1 -b -i "${PWD}/${patch}"

echo -n "Moving /sbin/splash to /sbin/splash.bin:"
if [ -f /sbin/splash.bin ]; then
	echo -e "\nMhm, /sbin/splash.bin already exists, leaving it untouched!"
else
	mv /sbin/splash /sbin/splash.bin
	echo " OK"
fi

echo -n "Installing wrapper script /sbin/splash:"
if [ -f /sbin/splash ]; then
	echo -e "\nMhm, /sbin/splash already exists, leaving it untouched!"
else
	install -m 755 "${PWD}/files/splash" /sbin/
	echo " OK"
fi

echo -n "Installing 'bootanim' to /sbin:"
install -m 755 "${PWD}/files/bootanim" /sbin/
echo " OK"

echo -n "Installing config file to /etc/conf.d/bootsplash.conf"
install -m 644 "${PWD}/files/bootsplash.conf" /etc/conf.d/
echo " OK"

echo -n "Removing bootsplash script from runlevels:"
rc-update del bootsplash &>/dev/null
echo " OK"

echo "Done."
